==> crocoddyl-2.0.2.tar.gz: crocoddyl-2.0.2/bindings/python/crocoddyl/core/activations/quadratic-flat-exp.cpp <==
///////////////////////////////////////////////////////////////////////////////
// BSD 3-Clause License
//
// Copyright (C) 2020-2023, LAAS-CNRS, University of Edinburgh
//                          Heriot-Watt University
// Copyright note valid unless otherwise stated in individual files.
// All rights reserved.
///////////////////////////////////////////////////////////////////////////////

#include "crocoddyl/core/activations/quadratic-flat-exp.hpp"

#include "python/crocoddyl/core/activation-base.hpp"
#include "python/crocoddyl/core/core.hpp"
#include "python/crocoddyl/utils/copyable.hpp"

namespace crocoddyl {
namespace python {

void exposeActivationQuadFlatExp() {
  boost::python::register_ptr_to_python<
      boost::shared_ptr<ActivationModelQuadFlatExp> >();

  bp::class_<ActivationModelQuadFlatExp, bp::bases<ActivationModelAbstract> >(
      "ActivationModelQuadFlatExp",
      "Quadratic flat activation model.\n\n"
      "A quadratic flat action describes a quadratic flat function that "
      "depends on the residual, i.e.\n"
      "1 - exp(-||r||^2 / alpha).",
      bp::init<int, double>(bp::args("self", "nr", "alpha"),
                            "Initialize the activation model.\n\n"
                            ":param nr: dimension of the cost-residual vector"
                            "param alpha: width of quadratic basin near zero"))
      .def("calc", &ActivationModelQuadFlatExp::calc,
           bp::args("self", "data", "r"),
           "Compute the 1 - exp(-||r||^2 / alpha).\n\n"
           ":param data: activation data\n"
           ":param r: residual vector")
      .def("calcDiff", &ActivationModelQuadFlatExp::calcDiff,
           bp::args("self", "data", "r"),
           "Compute the derivatives of a quadratic flat function.\n\n"
           "Note that the Hessian is constant, so we don't write again this "
           "value.\n"
           ":param data: activation data\n"
           ":param r: residual vector \n")
      .def("createData", &ActivationModelQuadFlatExp::createData,
           bp::args("self"), "Create the quadratic flat activation data.\n\n")
      .add_property(
          "alpha", bp::make_function(&ActivationModelQuadFlatExp::get_alpha),
          bp::make_function(&ActivationModelQuadFlatExp::set_alpha), "alpha")
      .def(CopyableVisitor<ActivationModelQuadFlatExp>());
}

}  // namespace python
}  // namespace crocoddyl

==> crocoddyl-2.2.0.tar.gz: crocoddyl-2.2.0/bindings/python/crocoddyl/core/activations/quadratic-flat-exp.cpp <==
///////////////////////////////////////////////////////////////////////////////
// BSD 3-Clause License
//
// Copyright (C) 2020-2024, LAAS-CNRS, University of Edinburgh
//                          Heriot-Watt University
// Copyright note valid unless otherwise stated in individual files.
// All rights reserved.
///////////////////////////////////////////////////////////////////////////////

#include "crocoddyl/core/activations/quadratic-flat-exp.hpp"

#include "python/crocoddyl/core/activation-base.hpp"
#include "python/crocoddyl/core/core.hpp"
#include "python/crocoddyl/utils/copyable.hpp"

namespace crocoddyl {
namespace python {

void exposeActivationQuadFlatExp() {
  boost::python::register_ptr_to_python<
      boost::shared_ptr<ActivationModelQuadFlatExp> >();

  bp::class_<ActivationModelQuadFlatExp, bp::bases<ActivationModelAbstract> >(
      "ActivationModelQuadFlatExp",
      "Quadratic flat activation model.\n\n"
      "A quadratic flat action describes a quadratic flat function that "
      "depends on the residual, i.e.\n"
      "1 - exp(-||r||^2 / alpha).",
      bp::init<std::size_t, double>(
          bp::args("self", "nr", "alpha"),
          "Initialize the activation model.\n\n"
          ":param nr: dimension of the cost-residual vector"
          "param alpha: width of quadratic basin near zero"))
      .def("calc", &ActivationModelQuadFlatExp::calc,
           bp::args("self", "data", "r"),
           "Compute the 1 - exp(-||r||^2 / alpha).\n\n"
           ":param data: activation data\n"
           ":param r: residual vector")
      .def("calcDiff", &ActivationModelQuadFlatExp::calcDiff,
           bp::args("self", "data", "r"),
           "Compute the derivatives of a quadratic flat function.\n\n"
           "Note that the Hessian is constant, so we don't write again this "
           "value.\n"
           ":param data: activation data\n"
           ":param r: residual vector \n")
      .def("createData", &ActivationModelQuadFlatExp::createData,
           bp::args("self"), "Create the quadratic flat activation data.\n\n")
      .add_property(
          "alpha", bp::make_function(&ActivationModelQuadFlatExp::get_alpha),
          bp::make_function(&ActivationModelQuadFlatExp::set_alpha), "alpha")
      .def(CopyableVisitor<ActivationModelQuadFlatExp>());
}

}  // namespace python
}  // namespace crocoddyl
